Re: [PATCH] Disable OpenSSL SHA1 implementation by default
- From
Jeff King <peff@peff.net>
- Date
- Feb 26, 2010, 22:40 UTC
- Message-ID
- <20100226224011.GB24370@sigill.intra.peff.net>
- In-Reply-To
- <ca433831002261333n4165d450k40e5feae72937cdc@mail.gmail.com>
On Fri, Feb 26, 2010 at 04:33:23PM -0500, Mark Lodato wrote:
> > Which is almost a 12% speedup by dropping openssl. > > I got about an 8% speedup on this test.
Thanks for more data. It looks like the patch is probably a win for me (depending on how you slice the workload), and definitely a win for you, then. So probably it is a sane thing to change the default.
I suspect the reason I got more of a speedup for "make test" is that I don't do the svn or cvs tests, both of which are really slow and won't be improved by the patch. If you have either installed, then that is diluting your speedup.
-Peff